==> ec2-1.131.0-sources.jar: software/amazon/awscdk/services/ec2/CfnTransitGatewayRouteProps.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Properties for defining a `AWS::EC2::TransitGatewayRoute`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.42.0 (build 5f6b62c)", date = "2021-11-07T11:28:21.886Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.CfnTransitGatewayRouteProps")
@software.amazon.jsii.Jsii.Proxy(CfnTransitGatewayRouteProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnTransitGatewayRouteProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::EC2::TransitGatewayRoute.TransitGatewayRouteTableId`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getTransitGatewayRouteTableId();

    /**
     * `AWS::EC2::TransitGatewayRoute.Blackhole`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getBlackhole() {
        return null;
    }

    /**
     * `AWS::EC2::TransitGatewayRoute.DestinationCidrBlock`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getDestinationCidrBlock() {
        return null;
    }

    /**
     * `AWS::EC2::TransitGatewayRoute.TransitGatewayAttachmentId`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getTransitGatewayAttachmentId() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnTransitGatewayRouteProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnTransitGatewayRouteProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnTransitGatewayRouteProps> {
        private java.lang.String transitGatewayRouteTableId;
        private java.lang.Object blackhole;
        private java.lang.String destinationCidrBlock;
        private java.lang.String transitGatewayAttachmentId;

        /**
         * Sets the value of {@link CfnTransitGatewayRouteProps#getTransitGatewayRouteTableId}
         * @param transitGatewayRouteTableId `AWS::EC2::TransitGatewayRoute.TransitGatewayRouteTableId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder transitGatewayRouteTableId(java.lang.String transitGatewayRouteTableId) {
            this.transitGatewayRouteTableId = transitGatewayRouteTableId;
            return this;
        }

        /**
         * Sets the value of {@link CfnTransitGatewayRouteProps#getBlackhole}
         * @param blackhole `AWS::EC2::TransitGatewayRoute.Blackhole`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder blackhole(java.lang.Boolean blackhole) {
            this.blackhole = blackhole;
            return this;
        }

        /**
         * Sets the value of {@link CfnTransitGatewayRouteProps#getBlackhole}
         * @param blackhole `AWS::EC2::TransitGatewayRoute.Blackhole`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder blackhole(software.amazon.awscdk.core.IResolvable blackhole) {
            this.blackhole = blackhole;
            return this;
        }

        /**
         * Sets the value of {@link CfnTransitGatewayRouteProps#getDestinationCidrBlock}
         * @param destinationCidrBlock `AWS::EC2::TransitGatewayRoute.DestinationCidrBlock`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder destinationCidrBlock(java.lang.String destinationCidrBlock) {
            this.destinationCidrBlock = destinationCidrBlock;
            return this;
        }

        /**
         * Sets the value of {@link CfnTransitGatewayRouteProps#getTransitGatewayAttachmentId}
         * @param transitGatewayAttachmentId `AWS::EC2::TransitGatewayRoute.TransitGatewayAttachmentId`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder transitGatewayAttachmentId(java.lang.String transitGatewayAttachmentId) {
            this.transitGatewayAttachmentId = transitGatewayAttachmentId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnTransitGatewayRouteProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnTransitGatewayRouteProps build() {
            return new Jsii$Proxy(transitGatewayRouteTableId, blackhole, destinationCidrBlock, transitGatewayAttachmentId);
        }
    }

    /**
     * An implementation for {@link CfnTransitGatewayRouteProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnTransitGatewayRouteProps {
        private final java.lang.String transitGatewayRouteTableId;
        private final java.lang.Object blackhole;
        private final java.lang.String destinationCidrBlock;
        private final java.lang.String transitGatewayAttachmentId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.transitGatewayRouteTableId = software.amazon.jsii.Kernel.get(this, "transitGatewayRouteTableId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.blackhole = software.amazon.jsii.Kernel.get(this, "blackhole", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.destinationCidrBlock = software.amazon.jsii.Kernel.get(this, "destinationCidrBlock", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.transitGatewayAttachmentId = software.amazon.jsii.Kernel.get(this, "transitGatewayAttachmentId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String transitGatewayRouteTableId, final java.lang.Object blackhole, final java.lang.String destinationCidrBlock, final java.lang.String transitGatewayAttachmentId) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.transitGatewayRouteTableId = java.util.Objects.requireNonNull(transitGatewayRouteTableId, "transitGatewayRouteTableId is required");
            this.blackhole = blackhole;
            this.destinationCidrBlock = destinationCidrBlock;
            this.transitGatewayAttachmentId = transitGatewayAttachmentId;
        }

        @Override
        public final java.lang.String getTransitGatewayRouteTableId() {
            return this.transitGatewayRouteTableId;
        }

        @Override
        public final java.lang.Object getBlackhole() {
            return this.blackhole;
        }

        @Override
        public final java.lang.String getDestinationCidrBlock() {
            return this.destinationCidrBlock;
        }

        @Override
        public final java.lang.String getTransitGatewayAttachmentId() {
            return this.transitGatewayAttachmentId;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("transitGatewayRouteTableId", om.valueToTree(this.getTransitGatewayRouteTableId()));
            if (this.getBlackhole() != null) {
                data.set("blackhole", om.valueToTree(this.getBlackhole()));
            }
            if (this.getDestinationCidrBlock() != null) {
                data.set("destinationCidrBlock", om.valueToTree(this.getDestinationCidrBlock()));
            }
            if (this.getTransitGatewayAttachmentId() != null) {
                data.set("transitGatewayAttachmentId", om.valueToTree(this.getTransitGatewayAttachmentId()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-ec2.CfnTransitGatewayRouteProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnTransitGatewayRouteProps.Jsii$Proxy that = (CfnTransitGatewayRouteProps.Jsii$Proxy) o;

            if (!transitGatewayRouteTableId.equals(that.transitGatewayRouteTableId)) return false;
            if (this.blackhole != null ? !this.blackhole.equals(that.blackhole) : that.blackhole != null) return false;
            if (this.destinationCidrBlock != null ? !this.destinationCidrBlock.equals(that.destinationCidrBlock) : that.destinationCidrBlock != null) return false;
            return this.transitGatewayAttachmentId != null ? this.transitGatewayAttachmentId.equals(that.transitGatewayAttachmentId) : that.transitGatewayAttachmentId == null;
        }

        @Override
        public final int hashCode() {
            int result = this.transitGatewayRouteTableId.hashCode();
            result = 31 * result + (this.blackhole != null ? this.blackhole.hashCode() : 0);
            result = 31 * result + (this.destinationCidrBlock != null ? this.destinationCidrBlock.hashCode() : 0);
            result = 31 * result + (this.transitGatewayAttachmentId != null ? this.transitGatewayAttachmentId.hashCode() : 0);
            return result;
        }
    }
}

==> ec2-1.133.0-sources.jar: software/amazon/awscdk/services/ec2/CfnTransitGatewayRouteProps.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Properties for defining a `AWS::EC2::TransitGatewayRoute`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.ec2.*;
 * CfnTransitGatewayRouteProps cfnTransitGatewayRouteProps = CfnTransitGatewayRouteProps.builder()
 *         .transitGatewayRouteTableId("transitGatewayRouteTableId")
 *         // the properties below are optional
 *         .blackhole(false)
 *         .destinationCidrBlock("destinationCidrBlock")
 *         .transitGatewayAttachmentId("transitGatewayAttachmentId")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.45.0 (build 61747b6)", date = "2021-11-19T21:31:10.509Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.CfnTransitGatewayRouteProps")
@software.amazon.jsii.Jsii.Proxy(CfnTransitGatewayRouteProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnTransitGatewayRouteProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::EC2::TransitGatewayRoute.Blackhole`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getBlackhole() {
        return null;
    }

    /**
     * `AWS::EC2::TransitGatewayRoute.DestinationCidrBlock`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getDestinationCidrBlock() {
        return null;
    }

    /**
     * `AWS::EC2::TransitGatewayRoute.TransitGatewayAttachmentId`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getTransitGatewayAttachmentId() {
        return null;
    }

    /**
     * `AWS::EC2::TransitGatewayRoute.TransitGatewayRouteTableId`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getTransitGatewayRouteTableId();

    /**
     * @return a {@link Builder} of {@link CfnTransitGatewayRouteProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnTransitGatewayRouteProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnTransitGatewayRouteProps> {
        java.lang.Object blackhole;
        java.lang.String destinationCidrBlock;
        java.lang.String transitGatewayAttachmentId;
        java.lang.String transitGatewayRouteTableId;

        /**
         * Sets the value of {@link CfnTransitGatewayRouteProps#getBlackhole}
         * @param blackhole `AWS::EC2::TransitGatewayRoute.Blackhole`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder blackhole(java.lang.Boolean blackhole) {
            this.blackhole = blackhole;
            return this;
        }

        /**
         * Sets the value of {@link CfnTransitGatewayRouteProps#getBlackhole}
         * @param blackhole `AWS::EC2::TransitGatewayRoute.Blackhole`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder blackhole(software.amazon.awscdk.core.IResolvable blackhole) {
            this.blackhole = blackhole;
            return this;
        }

        /**
         * Sets the value of {@link CfnTransitGatewayRouteProps#getDestinationCidrBlock}
         * @param destinationCidrBlock `AWS::EC2::TransitGatewayRoute.DestinationCidrBlock`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder destinationCidrBlock(java.lang.String destinationCidrBlock) {
            this.destinationCidrBlock = destinationCidrBlock;
            return this;
        }

        /**
         * Sets the value of {@link CfnTransitGatewayRouteProps#getTransitGatewayAttachmentId}
         * @param transitGatewayAttachmentId `AWS::EC2::TransitGatewayRoute.TransitGatewayAttachmentId`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder transitGatewayAttachmentId(java.lang.String transitGatewayAttachmentId) {
            this.transitGatewayAttachmentId = transitGatewayAttachmentId;
            return this;
        }

        /**
         * Sets the value of {@link CfnTransitGatewayRouteProps#getTransitGatewayRouteTableId}
         * @param transitGatewayRouteTableId `AWS::EC2::TransitGatewayRoute.TransitGatewayRouteTableId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder transitGatewayRouteTableId(java.lang.String transitGatewayRouteTableId) {
            this.transitGatewayRouteTableId = transitGatewayRouteTableId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnTransitGatewayRouteProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnTransitGatewayRouteProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnTransitGatewayRouteProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnTransitGatewayRouteProps {
        private final java.lang.Object blackhole;
        private final java.lang.String destinationCidrBlock;
        private final java.lang.String transitGatewayAttachmentId;
        private final java.lang.String transitGatewayRouteTableId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.blackhole = software.amazon.jsii.Kernel.get(this, "blackhole", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.destinationCidrBlock = software.amazon.jsii.Kernel.get(this, "destinationCidrBlock", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.transitGatewayAttachmentId = software.amazon.jsii.Kernel.get(this, "transitGatewayAttachmentId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.transitGatewayRouteTableId = software.amazon.jsii.Kernel.get(this, "transitGatewayRouteTableId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.blackhole = builder.blackhole;
            this.destinationCidrBlock = builder.destinationCidrBlock;
            this.transitGatewayAttachmentId = builder.transitGatewayAttachmentId;
            this.transitGatewayRouteTableId = java.util.Objects.requireNonNull(builder.transitGatewayRouteTableId, "transitGatewayRouteTableId is required");
        }

        @Override
        public final java.lang.Object getBlackhole() {
            return this.blackhole;
        }

        @Override
        public final java.lang.String getDestinationCidrBlock() {
            return this.destinationCidrBlock;
        }

        @Override
        public final java.lang.String getTransitGatewayAttachmentId() {
            return this.transitGatewayAttachmentId;
        }

        @Override
        public final java.lang.String getTransitGatewayRouteTableId() {
            return this.transitGatewayRouteTableId;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getBlackhole() != null) {
                data.set("blackhole", om.valueToTree(this.getBlackhole()));
            }
            if (this.getDestinationCidrBlock() != null) {
                data.set("destinationCidrBlock", om.valueToTree(this.getDestinationCidrBlock()));
            }
            if (this.getTransitGatewayAttachmentId() != null) {
                data.set("transitGatewayAttachmentId", om.valueToTree(this.getTransitGatewayAttachmentId()));
            }
            data.set("transitGatewayRouteTableId", om.valueToTree(this.getTransitGatewayRouteTableId()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-ec2.CfnTransitGatewayRouteProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnTransitGatewayRouteProps.Jsii$Proxy that = (CfnTransitGatewayRouteProps.Jsii$Proxy) o;

            if (this.blackhole != null ? !this.blackhole.equals(that.blackhole) : that.blackhole != null) return false;
            if (this.destinationCidrBlock != null ? !this.destinationCidrBlock.equals(that.destinationCidrBlock) : that.destinationCidrBlock != null) return false;
            if (this.transitGatewayAttachmentId != null ? !this.transitGatewayAttachmentId.equals(that.transitGatewayAttachmentId) : that.transitGatewayAttachmentId != null) return false;
            return this.transitGatewayRouteTableId.equals(that.transitGatewayRouteTableId);
        }

        @Override
        public final int hashCode() {
            int result = this.blackhole != null ? this.blackhole.hashCode() : 0;
            result = 31 * result + (this.destinationCidrBlock != null ? this.destinationCidrBlock.hashCode() : 0);
            result = 31 * result + (this.transitGatewayAttachmentId != null ? this.transitGatewayAttachmentId.hashCode() : 0);
            result = 31 * result + (this.transitGatewayRouteTableId.hashCode());
            return result;
        }
    }
}
